@@ -10,6 +10,7 @@
 #endif 
 
 #include<QGLViewer/qglviewer.h>
+#include<QGLViewer/manipulatedFrame.h>
 #include<QGLViewer/constraint.h>
 #include<set>
 
@@ -49,10 +50,11 @@ class GLViewer : public QGLViewer
 		float			cut_plane;
 		int			cut_plane_delta;
 		bool			gridSubdivide;
+		long			last;
 		int manipulatedClipPlane;
 		set<int> boundClipPlanes;
 		shared_ptr<qglviewer::LocalConstraint> xyPlaneConstraint;
-		string strBoundGroup(){string ret;FOREACH(int i, boundClipPlanes) ret+=" "+lexical_cast<string>(i+1);return ret;}
+		string strBoundGroup(){string ret;FOREACH(int i, boundClipPlanes) ret+=" "+boost::lexical_cast<string>(i+1);return ret;}
 		boost::posix_time::ptime last_user_event;
 
      public:
