@@ -25,26 +25,23 @@
 #include<boost/algorithm/string/case_conv.hpp>
 #include<yade/lib/serialization/ObjectIO.hpp>
 #include<yade/lib/pyutil/gil.hpp>
-
+#include<QGLViewer/manipulatedCameraFrame.h>
 
 #include<QtGui/qevent.h>
 
-using namespace boost;
-
 #ifdef YADE_GL2PS
 	#include<gl2ps.h>
 #endif
 
 void GLViewer::mouseMovesCamera(){
-  camera()->frame()->setWheelSensitivity(-1.0f);
-  
   setWheelBinding(Qt::ShiftModifier , FRAME, ZOOM);
   setWheelBinding(Qt::NoModifier, CAMERA, ZOOM);
 
 #if QGLVIEWER_VERSION>=0x020500
   setMouseBinding(Qt::ShiftModifier, Qt::LeftButton, SELECT);
   
-  setMouseBinding(Qt::ShiftModifier, Qt::LeftButton | Qt::RightButton, FRAME, ZOOM);
+  setMouseBinding(Qt::ShiftModifier, Qt::LeftButton, FRAME, ZOOM);
+  setMouseBinding(Qt::ShiftModifier, Qt::RightButton, FRAME, ZOOM);
   setMouseBinding(Qt::ShiftModifier, Qt::MidButton, FRAME, TRANSLATE);
   setMouseBinding(Qt::ShiftModifier, Qt::RightButton, FRAME, ROTATE);
     
@@ -54,7 +51,6 @@ void GLViewer::mouseMovesCamera(){
   setMouseBinding(Qt::NoModifier, Qt::RightButton, CAMERA, TRANSLATE);
 #else
   setMouseBinding(Qt::SHIFT + Qt::LeftButton, SELECT);
-  
   setMouseBinding(Qt::SHIFT + Qt::LeftButton + Qt::RightButton, FRAME, ZOOM);
   setMouseBinding(Qt::SHIFT + Qt::MidButton, FRAME, TRANSLATE);
   setMouseBinding(Qt::SHIFT + Qt::RightButton, FRAME, ROTATE);
@@ -63,6 +59,7 @@ void GLViewer::mouseMovesCamera(){
   setMouseBinding(Qt::MidButton, CAMERA, ZOOM);
   setMouseBinding(Qt::LeftButton, CAMERA, ROTATE);
   setMouseBinding(Qt::RightButton, CAMERA, TRANSLATE);
+  camera()->frame()->setWheelSensitivity(-1.0f);
 #endif
 };
 
@@ -102,7 +99,6 @@ void GLViewer::mouseDoubleClickEvent(QMouseEvent *event){
 #endif
 	switch (event->button()){
 		case Qt::LeftButton:  manipulatedFrame()->alignWithFrame(NULL,true); LOG_DEBUG("Aligning cutting plane"); break;
-		// case Qt::RightButton: projectOnLine(camera->position(), camera->viewDirection()); break;
 		default: break; // avoid warning
 	}
 }
@@ -113,8 +109,6 @@ void GLViewer::wheelEvent(QWheelEvent* event){
 	if(manipulatedClipPlane<0){ QGLViewer::wheelEvent(event); return; }
 	assert(manipulatedClipPlane<renderer->numClipPlanes);
 	float distStep=1e-3*sceneRadius();
-	//const float wheelSensitivityCoef = 8E-4f;
-	//Vec trans(0.0, 0.0, -event->delta()*wheelSensitivity()*wheelSensitivityCoef*(camera->position()-position()).norm());
 	float dist=event->delta()*manipulatedFrame()->wheelSensitivity()*distStep;
 	Vector3r normal=renderer->clipPlaneSe3[manipulatedClipPlane].orientation*Vector3r(0,0,1);
 	qglviewer::Vec newPos=manipulatedFrame()->position()+qglviewer::Vec(normal[0],normal[1],normal[2])*dist;
