@@ -12,9 +12,9 @@
 // #define TAUCS_LIB //comment this if TAUCS lib is not available, it will disable PARDISO lib as well
 
 #ifdef EIGENSPARSE_LIB
-	#include <eigen3/Eigen/Sparse>
-	#include <eigen3/Eigen/SparseCore>
-	#include <eigen3/Eigen/CholmodSupport>
+	#include <Eigen/Sparse>
+	#include <Eigen/SparseCore>
+	#include <Eigen/CholmodSupport>
 #endif
 #ifdef TAUCS_LIB
 #define TAUCS_CORE_DOUBLE
@@ -34,7 +34,7 @@ using namespace std;
 
 namespace CGT {
 
-template<class FlowType>
+template<class _Tesselation, class FlowType=FlowBoundingSphere<_Tesselation> >
 class FlowBoundingSphereLinSolv : public FlowType
 {
 public:
@@ -44,18 +44,20 @@ public:
 	using FlowType::T;
 	using FlowType::currentTes;
 	using FlowType::boundary;
-	using FlowType::y_min_id;
-	using FlowType::y_max_id;
-	using FlowType::DEBUG_OUT;
-	using FlowType::TOLERANCE;
-	using FlowType::RELAX;
+	using FlowType::yMinId;
+	using FlowType::yMaxId;
+	using FlowType::debugOut;
+	using FlowType::tolerance;
+	using FlowType::relax;
 	using FlowType::fluidBulkModulus;
 	using FlowType::reApplyBoundaryConditions;
 	using FlowType::pressureChanged;
 	using FlowType::computedOnce;
+	using FlowType::resetNetwork;
+	using FlowType::tesselation;
 
 	//! TAUCS DECs
-	vector<Finite_cells_iterator> orderedCells;
+	vector<FiniteCellsIterator> orderedCells;
 	bool isLinearSystemSet;
 	bool isFullLinearSystemGSSet;
 	bool areCellsOrdered;//true when orderedCells is filled, turn it false after retriangulation
@@ -97,7 +99,7 @@ public:
 	vector<int> T_jn;//(size+1);
 	vector<int> T_ia;//(size*5);
 	vector<double> T_f;//(size); // right-hand size vector object
-	vector<Cell_handle> T_cells;//(size)
+	vector<CellHandle> T_cells;//(size)
 	int T_index;
 
 	vector<double> T_b;
@@ -143,35 +145,35 @@ public:
 	FlowBoundingSphereLinSolv();
 
 	///Linear system solve
-	virtual int SetLinearSystem(Real dt);
-	void VectorizedGaussSeidel(Real dt);
-	virtual int SetLinearSystemFullGS(Real dt);
+	virtual int setLinearSystem(Real dt);
+	void vectorizedGaussSeidel(Real dt);
+	virtual int setLinearSystemFullGS(Real dt);
 	
-	int TaucsSolveTest();
-	int TaucsSolve(Real dt);
-	int PardisoSolveTest();
-	int PardisoSolve(Real dt);
+	int taucsSolveTest();
+	int taucsSolve(Real dt);
+	int pardisoSolveTest();
+	int pardisoSolve(Real dt);
 	int eigenSolve(Real dt);
 	
-	void CopyGsToCells();
-	void CopyCellsToGs(Real dt);
+	void copyGsToCells();
+	void copyCellsToGs(Real dt);
 	
-	void CopyLinToCells();
-	void CopyCellsToLin(Real dt);
-	void swap_fwd (double* v, int i);
-	void swap_fwd (int* v, int i);
-	void sort_v(int k1, int k2, int* is, double* ds);
+	void copyLinToCells();
+	void copyCellsToLin(Real dt);
+	void swapFwd (double* v, int i);
+	void swapFwd (int* v, int i);
+	void sortV(int k1, int k2, int* is, double* ds);
 
-	virtual void GaussSeidel (Real dt) {
+	virtual void gaussSeidel (Real dt) {
 		switch (useSolver) {
 		case 0:
-			VectorizedGaussSeidel(dt);
+			vectorizedGaussSeidel(dt);
 			break;
 		case 1:
-			TaucsSolve(dt);
+			taucsSolve(dt);
 			break;
 		case 2:
-			PardisoSolve(dt);
+			pardisoSolve(dt);
 			break;
 		case 3:
 			eigenSolve(dt);
@@ -179,7 +181,7 @@ public:
 		}
 		computedOnce=true;
 	}
-	virtual void ResetNetwork();
+	virtual void resetNetwork();
 };
 
 } //namespace CGT
