@@ -1,3 +1,6 @@
+// 2011 © Bruno Chareyre <bruno.chareyre@hmg.inpg.fr>
+// 2012 © Kneib Francois <francois.kneib@irstea.fr>
+
 #include "Cylinder.hpp"
 #include<yade/pkg/common/Sphere.hpp>
 #ifdef YADE_OPENGL
@@ -741,13 +744,13 @@ void Law2_CylScGeom6D_CohFrictPhys_CohesionMoment::go(shared_ptr<IGeom>& ig, sha
 
     if (currentContactPhysics->fragile && (-Fn)> currentContactPhysics->normalAdhesion) {
         // BREAK due to tension
-        scene->interactions->requestErase(contact->getId1(),contact->getId2());
+        scene->interactions->requestErase(contact);
     } else {
         if ((-Fn)> currentContactPhysics->normalAdhesion) {//normal plasticity
             Fn=-currentContactPhysics->normalAdhesion;
             currentContactPhysics->unp = un+currentContactPhysics->normalAdhesion/currentContactPhysics->kn;
             if (currentContactPhysics->unpMax && currentContactPhysics->unp<currentContactPhysics->unpMax)
-                scene->interactions->requestErase(contact->getId1(),contact->getId2());
+                scene->interactions->requestErase(contact);
         }
         currentContactPhysics->normalForce = Fn*geom->normal;
         Vector3r& shearForce = geom->rotate(currentContactPhysics->shearForce);
@@ -823,13 +826,13 @@ void Law2_ChCylGeom6D_CohFrictPhys_CohesionMoment::go(shared_ptr<IGeom>& ig, sha
     
     if (currentContactPhysics->fragile && (-Fn)> currentContactPhysics->normalAdhesion) {
         // BREAK due to tension
-        scene->interactions->requestErase(contact->getId1(),contact->getId2());
+        scene->interactions->requestErase(contact);
     } else {
         if ((-Fn)> currentContactPhysics->normalAdhesion) {//normal plasticity
             Fn=-currentContactPhysics->normalAdhesion;
             currentContactPhysics->unp = un+currentContactPhysics->normalAdhesion/currentContactPhysics->kn;
             if (currentContactPhysics->unpMax && currentContactPhysics->unp<currentContactPhysics->unpMax)
-                scene->interactions->requestErase(contact->getId1(),contact->getId2());
+                scene->interactions->requestErase(contact);
         }
     
         
