@@ -7,7 +7,7 @@ void Recorder::openAndCheck(){
 	assert(!out.is_open());
 	
 	std::string fileTemp = file;
-	if (addIterNum) fileTemp+="-" + lexical_cast<string>(scene->iter);
+	if (addIterNum) fileTemp+="-" + boost::lexical_cast<string>(scene->iter);
 	
 	if(fileTemp.empty()) throw ios_base::failure(__FILE__ ": Empty filename.");
 	out.open(fileTemp.c_str(), truncate ? fstream::trunc : fstream::app);
