@@ -33,22 +33,6 @@ void Ip2_FrictMat_FrictMat_FrictPhys::go( const shared_ptr<Material>& b1
 	Ra=sphCont->refR1>0?sphCont->refR1:sphCont->refR2;
 	Rb=sphCont->refR2>0?sphCont->refR2:sphCont->refR1;
 	
-	//The two contitions above are used in the case of a ViscElMat/FrictMat contact, if kn and ks are set for the ViscElMat. Young and Poisson are deduced. This is not a perfect solution and the user should set young/poisson only.
-	if( b1->getClassIndex()==ViscElMat::getClassIndexStatic()){
-		const shared_ptr<ViscElMat>& mat1 = YADE_PTR_CAST<ViscElMat>(b1);
-		if( (!isnan(mat1->kn)) && (!isnan(mat1->ks)) ){
-			mat1->young=mat1->kn/(2.*Ra);
-			mat1->poisson=mat1->ks/mat1->kn;
-		}
-	}
-	if( b2->getClassIndex()==ViscElMat::getClassIndexStatic()){
-		const shared_ptr<ViscElMat>& mat2 = YADE_PTR_CAST<ViscElMat>(b2);
-		if( (!isnan(mat2->kn)) && (!isnan(mat2->ks)) ){
-			mat2->young=mat2->kn/(2.*Rb);
-			mat2->poisson=mat2->ks/mat2->kn;
-		}
-	}
-	
 	interaction->phys = shared_ptr<FrictPhys>(new FrictPhys());
 	const shared_ptr<FrictPhys>& contactPhysics = YADE_PTR_CAST<FrictPhys>(interaction->phys);
 	Real Ea 	= mat1->young;
@@ -91,7 +75,7 @@ void Ip2_FrictMat_FrictMat_ViscoFrictPhys::go( const shared_ptr<Material>& b1
 	//harmonic average of the two stiffnesses when (Ri.Ei/2) is the stiffness of a contact point on sphere "i"
 	Real Kn = 2*Ea*Ra*Eb*Rb/(Ea*Ra+Eb*Rb);
 	//same for shear stiffness
-	Real Ks = 2*Ea*Ra*Va*Eb*Rb*Vb/(Ea*Ra*Va+Eb*Rb*Va);
+	Real Ks = 2*Ea*Ra*Va*Eb*Rb*Vb/(Ea*Ra*Va+Eb*Rb*Vb);
 
 	Real frictionAngle = (!frictAngle) ? std::min(mat1->frictionAngle,mat2->frictionAngle) : (*frictAngle)(mat1->id,mat2->id,mat1->frictionAngle,mat2->frictionAngle);
 	contactPhysics->tangensOfFrictionAngle = std::tan(frictionAngle);
